@@ -30,7 +30,7 @@ TODO: Make interfaces to the following fitpack functions:
 
 __all__ = ['splrep', 'splprep', 'splev', 'splint', 'sproot', 'spalde',
     'bisplrep', 'bisplev', 'insert']
-__version__ = "$Revision: 2762 $"[10:-1]
+__version__ = "$Revision: 4939 $"[10:-1]
 import _fitpack
 from numpy import atleast_1d, array, ones, zeros, sqrt, ravel, transpose, \
      dot, sin, cos, pi, arange, empty, int32
@@ -170,8 +170,18 @@ def splprep(x,w=None,u=None,ub=None,ue=None,k=3,task=0,s=None,t=None,
     See also:
       splrep, splev, sproot, spalde, splint - evaluation, roots, integral
       bisplrep, bisplev - bivariate splines
-      UnivariateSpline, BivariateSpline - an alternative wrapping 
+      UnivariateSpline, BivariateSpline - an alternative wrapping
               of the FITPACK functions
+
+    Notes:
+       Dierckx P. : Algorithms for smoothing data with periodic and
+                    parametric splines, Computer Graphics and Image
+                    Processing 20 (1982) 171-184.
+       Dierckx P. : Algorithms for smoothing data with periodic and param-
+                    etric splines, report tw55, Dept. Computer Science,
+                    K.U.Leuven, 1981.
+       Dierckx P. : Curve and surface fitting with splines, Monographs on
+                    Numerical Analysis, Oxford University Press, 1993.
     """
     if task<=0:
         _parcur_cache = {'t': array([],float), 'wrk': array([],float),
@@ -316,21 +326,36 @@ def splrep(x,y,w=None,xb=None,xe=None,k=3,task=0,s=None,t=None,
     Remarks:
 
       See splev for evaluation of the spline and its derivatives.
-      
+
     Example:
-        
+
       x = linspace(0, 10, 10)
       y = sin(x)
       tck = splrep(x, y)
       x2 = linspace(0, 10, 200)
       y2 = splev(x2, tck)
       plot(x, y, 'o', x2, y2)
-      
+
     See also:
       splprep, splev, sproot, spalde, splint - evaluation, roots, integral
       bisplrep, bisplev - bivariate splines
-      UnivariateSpline, BivariateSpline - an alternative wrapping 
+      UnivariateSpline, BivariateSpline - an alternative wrapping
               of the FITPACK functions
+
+    Notes:
+
+    Based on algorithms described in:
+       Dierckx P. : An algorithm for smoothing, differentiation and integ-
+                    ration of experimental data using spline functions,
+                    J.Comp.Appl.Maths 1 (1975) 165-184.
+       Dierckx P. : A fast algorithm for smoothing data on a rectangular
+                    grid while using spline functions, SIAM J.Numer.Anal.
+                    19 (1982) 1286-1304.
+       Dierckx P. : An improved algorithm for curve fitting with spline
+                    functions, report tw54, Dept. Computer Science,K.U.
+                    Leuven, 1981.
+       Dierckx P. : Curve and surface fitting with splines, Monographs on
+                    Numerical Analysis, Oxford University Press, 1993.
     """
     if task<=0:
         _curfit_cache = {}
@@ -347,7 +372,7 @@ def splrep(x,y,w=None,xb=None,xe=None,k=3,task=0,s=None,t=None,
         raise TypeError, 'Lengths of the first three arguments (x,y,w) must be equal'
     if not (1<=k<=5):
         raise TypeError, 'Given degree of the spline (k=%d) is not supported. (1<=k<=5)'%(k)
-    if m<=k: raise TypeError, 'm>k must hold'     
+    if m<=k: raise TypeError, 'm>k must hold'
     if xb is None: xb=x[0]
     if xe is None: xe=x[-1]
     if not (-1<=task<=1): raise TypeError, 'task must be either -1,0, or 1'
@@ -434,8 +459,16 @@ def splev(x,tck,der=0):
     See also:
       splprep, splrep, sproot, spalde, splint - evaluation, roots, integral
       bisplrep, bisplev - bivariate splines
-      UnivariateSpline, BivariateSpline - an alternative wrapping 
+      UnivariateSpline, BivariateSpline - an alternative wrapping
               of the FITPACK functions
+
+    Notes:
+        de Boor C  : On calculating with b-splines, J. Approximation Theory
+                     6 (1972) 50-62.
+        Cox M.G.   : The numerical evaluation of b-splines, J. Inst. Maths
+                     Applics 10 (1972) 134-149.
+        Dierckx P. : Curve and surface fitting with splines, Monographs on
+                     Numerical Analysis, Oxford University Press, 1993.
     """
     t,c,k=tck
     try:
@@ -446,14 +479,14 @@ def splev(x,tck,der=0):
     if parametric:
         return map(lambda c,x=x,t=t,k=k,der=der:splev(x,[t,c,k],der),c)
     else:
-      if not (0<=der<=k):
-          raise ValueError,"0<=der=%d<=k=%d must hold"%(der,k)
-      x=myasarray(x)
-      y,ier=_fitpack._spl_(x,der,t,c,k)
-      if ier==10: raise ValueError,"Invalid input data"
-      if ier: raise TypeError,"An error occurred"
-      if len(y)>1: return y
-      return y[0]
+        if not (0<=der<=k):
+            raise ValueError,"0<=der=%d<=k=%d must hold"%(der,k)
+        x=myasarray(x)
+        y,ier=_fitpack._spl_(x,der,t,c,k)
+        if ier==10: raise ValueError,"Invalid input data"
+        if ier: raise TypeError,"An error occurred"
+        if len(y)>1: return y
+        return y[0]
 
 def splint(a,b,tck,full_output=0):
     """Evaluate the definite integral of a B-spline.
@@ -479,8 +512,14 @@ def splint(a,b,tck,full_output=0):
     See also:
       splprep, splrep, sproot, spalde, splev - evaluation, roots, integral
       bisplrep, bisplev - bivariate splines
-      UnivariateSpline, BivariateSpline - an alternative wrapping 
+      UnivariateSpline, BivariateSpline - an alternative wrapping
               of the FITPACK functions
+
+    Notes:
+        Gaffney P.W. : The calculation of indefinite integrals of b-splines
+                       J. Inst. Maths Applics 17 (1976) 37-41.
+        Dierckx P. : Curve and surface fitting with splines, Monographs on
+                     Numerical Analysis, Oxford University Press, 1993.
     """
     t,c,k=tck
     try:
@@ -517,8 +556,9 @@ def sproot(tck,mest=10):
     See also:
       splprep, splrep, splint, spalde, splev - evaluation, roots, integral
       bisplrep, bisplev - bivariate splines
-      UnivariateSpline, BivariateSpline - an alternative wrapping 
+      UnivariateSpline, BivariateSpline - an alternative wrapping
               of the FITPACK functions
+
     """
     t,c,k=tck
     if k==4: t=t[1:-1]
@@ -564,8 +604,16 @@ def spalde(x,tck):
     See also:
       splprep, splrep, splint, sproot, splev - evaluation, roots, integral
       bisplrep, bisplev - bivariate splines
-      UnivariateSpline, BivariateSpline - an alternative wrapping 
+      UnivariateSpline, BivariateSpline - an alternative wrapping
               of the FITPACK functions
+    Notes:
+    Based on algorithms from:
+        de Boor C : On calculating with b-splines, J. Approximation Theory
+                    6 (1972) 50-62.
+        Cox M.G.  : The numerical evaluation of b-splines, J. Inst. Maths
+                    applics 10 (1972) 134-149.
+       Dierckx P. : Curve and surface fitting with splines, Monographs on
+                    Numerical Analysis, Oxford University Press, 1993.
     """
     t,c,k=tck
     try:
@@ -576,17 +624,17 @@ def spalde(x,tck):
     if parametric:
         return _ntlist(map(lambda c,x=x,t=t,k=k:spalde(x,[t,c,k]),c))
     else:
-      try: x=x.tolist()
-      except:
-          try: x=list(x)
-          except: x=[x]
-      if len(x)>1:
-          return map(lambda x,tck=tck:spalde(x,tck),x)
-      d,ier=_fitpack._spalde(t,c,k,x[0])
-      if ier==0: return d
-      if ier==10:
-          raise TypeError,"Invalid input data. t(k)<=x<=t(n-k+1) must hold."
-      raise TypeError,"Unknown error"
+        try: x=x.tolist()
+        except:
+            try: x=list(x)
+            except: x=[x]
+        if len(x)>1:
+            return map(lambda x,tck=tck:spalde(x,tck),x)
+        d,ier=_fitpack._spalde(t,c,k,x[0])
+        if ier==0: return d
+        if ier==10:
+            raise TypeError,"Invalid input data. t(k)<=x<=t(n-k+1) must hold."
+        raise TypeError,"Unknown error"
 
 #def _curfit(x,y,w=None,xb=None,xe=None,k=3,task=0,s=None,t=None,
 #           full_output=0,nest=None,per=0,quiet=1):
@@ -601,7 +649,8 @@ def bisplrep(x,y,z,w=None,xb=None,xe=None,yb=None,ye=None,kx=3,ky=3,task=0,
     Description:
 
       Given a set of data points (x[i], y[i], z[i]) representing a surface
-      z=f(x,y), compute a B-spline representation of the surface.
+      z=f(x,y), compute a B-spline representation of the surface. Based on
+      the routine SURFIT from FITPACK.
 
     Inputs:
 
@@ -651,8 +700,17 @@ def bisplrep(x,y,z,w=None,xb=None,xe=None,yb=None,ye=None,kx=3,ky=3,task=0,
 
     See also:
       splprep, splrep, splint, sproot, splev - evaluation, roots, integral
-      UnivariateSpline, BivariateSpline - an alternative wrapping 
+      UnivariateSpline, BivariateSpline - an alternative wrapping
               of the FITPACK functions
+
+    Notes:
+    Based on algorithms from:
+       Dierckx P. : An algorithm for surface fitting with spline functions
+                    Ima J. Numer. Anal. 1 (1981) 267-283.
+       Dierckx P. : An algorithm for surface fitting with spline functions
+                    report tw50, Dept. Computer Science,K.U.Leuven, 1980.
+       Dierckx P. : Curve and surface fitting with splines, Monographs on
+                    Numerical Analysis, Oxford University Press, 1993.
     """
     x,y,z=map(myasarray,[x,y,z])
     x,y,z=map(ravel,[x,y,z])  # ensure 1-d arrays.
@@ -696,8 +754,11 @@ def bisplrep(x,y,z,w=None,xb=None,xe=None,yb=None,ye=None,kx=3,ky=3,task=0,
     bx,by=kx*v+ky+1,ky*u+kx+1
     b1,b2=bx,bx+v-ky
     if bx>by: b1,b2=by,by+u-kx
-    lwrk1=u*v*(2+b1+b2)+2*(u+v+km*(m+ne)+ne-kx-ky)+b2+1
-    lwrk2=u*v*(b2+1)+b2
+    try:
+        lwrk1=int32(u*v*(2+b1+b2)+2*(u+v+km*(m+ne)+ne-kx-ky)+b2+1)
+        lwrk2=int32(u*v*(b2+1)+b2)
+    except OverflowError:
+        raise OverflowError("Too many data points to interpolate")
     tx,ty,c,o = _fitpack._surfit(x,y,z,w,xb,xe,yb,ye,kx,ky,task,s,eps,
                                    tx,ty,nxest,nyest,wrk,lwrk1,lwrk2)
     _curfit_cache['tx']=tx
@@ -736,7 +797,7 @@ def bisplev(x,y,tck,dx=0,dy=0):
       Return a rank-2 array of spline function values (or spline derivative
       values) at points given by the cross-product of the rank-1 arrays x and y.
       In special cases, return an array or just a float if either x or y or
-      both are floats.
+      both are floats. Based on BISPEV from FITPACK.
 
     Inputs:
 
@@ -758,8 +819,17 @@ def bisplev(x,y,tck,dx=0,dy=0):
 
     See also:
       splprep, splrep, splint, sproot, splev - evaluation, roots, integral
-      UnivariateSpline, BivariateSpline - an alternative wrapping 
+      UnivariateSpline, BivariateSpline - an alternative wrapping
               of the FITPACK functions
+
+    Notes:
+    Based on algorithms from:
+       Dierckx P. : An algorithm for surface fitting with spline functions
+                    Ima J. Numer. Anal. 1 (1981) 267-283.
+       Dierckx P. : An algorithm for surface fitting with spline functions
+                    report tw50, Dept. Computer Science,K.U.Leuven, 1980.
+       Dierckx P. : Curve and surface fitting with splines, Monographs on
+                    Numerical Analysis, Oxford University Press, 1993.
     """
     tx,ty,c,kx,ky=tck
     if not (0<=dx<kx): raise ValueError,"0<=dx=%d<kx=%d must hold"%(dx,kx)
@@ -775,12 +845,34 @@ def bisplev(x,y,tck,dx=0,dy=0):
     if len(z[0])>1: return z[0]
     return z[0][0]
 
+def dblint(xa,xb,ya,yb,tck):
+    """Evaluate the integral of a spline over area [xa,xb] x [ya,yb].
+
+    Parameters
+    ----------
+    xa, xb : float
+        The end-points of the x integration interval.
+    ya, yb : float
+        The end-points of the y integration interval.
+    tck : list [tx, ty, c, kx, ky]
+        A sequence of length 5 returned by bisplrep containing the knot
+        locations tx, ty, the coefficients c, and the degrees kx, ky
+        of the spline.
+
+    Returns
+    -------
+    integ : float
+        The value of the resulting integral.
+    """
+    tx,ty,c,kx,ky=tck
+    return dfitpack.dblint(tx,ty,c,kx,ky,xb,xe,yb,ye)
+
 def insert(x,tck,m=1,per=0):
     """Insert knots into a B-spline.
 
     Description:
 
-      Given the knots and coefficients of a B-spline representation, create a 
+      Given the knots and coefficients of a B-spline representation, create a
       new B-spline with a knot inserted m times at point x.
       This is a wrapper around the FORTRAN routine insert of FITPACK.
 
@@ -797,12 +889,19 @@ def insert(x,tck,m=1,per=0):
 
       tck -- (t,c,k) a tuple containing the vector of knots, the B-spline
              coefficients, and the degree of the new spline.
-    
+
     Requirements:
         t(k+1) <= x <= t(n-k), where k is the degree of the spline.
         In case of a periodic spline (per != 0) there must be
            either at least k interior knots t(j) satisfying t(k+1)<t(j)<=x
-           or at least k interior knots t(j) satisfying x<=t(j)<t(n-k).    
+           or at least k interior knots t(j) satisfying x<=t(j)<t(n-k).
+
+    Notes:
+    Based on algorithms from:
+        Boehm W : Inserting new knots into b-spline curves. Computer Aided
+                  Design 12 (1980) 199-201.
+       Dierckx P. : Curve and surface fitting with splines, Monographs on
+                    Numerical Analysis, Oxford University Press, 1993.
     """
     t,c,k=tck
     try:
@@ -813,8 +912,8 @@ def insert(x,tck,m=1,per=0):
     if parametric:
         cc = []
         for c_vals in c:
-          tt, cc_val, kk = insert(x, [t, c_vals, k], m)
-          cc.append(cc_val)
+            tt, cc_val, kk = insert(x, [t, c_vals, k], m)
+            cc.append(cc_val)
         return (tt, cc, kk)
     else:
         tt, cc, ier = _fitpack._insert(per, t, c, k, x, m)
@@ -823,10 +922,10 @@ def insert(x,tck,m=1,per=0):
         return (tt, cc, k)
 
 if __name__ == "__main__":
-    import sys,string
+    import sys
     runtest=range(10)
     if len(sys.argv[1:])>0:
-        runtest=map(string.atoi,sys.argv[1:])
+        runtest=map(int,sys.argv[1:])
     put=sys.stdout.write
     def norm2(x):
         return dot(transpose(x),x)
