@@ -17,7 +17,9 @@ import types
 
 # Numpy imports.
 import numpy
-from numpy import array, take, concatenate, asarray, real, imag
+
+from numpy import array, take, concatenate, asarray, real, imag, \
+  deprecate_with_doc
 # Sadly, this module is still written with typecodes in mind.
 from numpy.oldnumeric import Float
 
@@ -107,7 +109,7 @@ def get_open_file(fileobject, mode='rb'):
                 if type(details) == type(()):
                     details = details + (fileobject,)
                 raise IOError, details
-    except AttributeError:
+    except (AttributeError, TypeError):
         # it is assumed that the fileobject is a python
         # file object if it can not be used in os.path.expanduser
         file = fileobject
@@ -167,7 +169,7 @@ class ascii_stream(object):
             return lines[:-1]
 
     def __del__(self):
-        if hasattr(self.file,'close') and self.should_close_file:
+        if hasattr(getattr(self, 'file', None),'close') and self.should_close_file:
             self.file.close()
 
     def __getitem__(self, item):
@@ -310,6 +312,10 @@ def convert_to_equal_lists(cols, atype):
     return cols, atype
 
 
+@deprecate_with_doc("""
+The functionality of read_array is in numpy.loadtxt which allows the same
+functionality using different syntax.
+""")
 def read_array(fileobject, separator=default, columns=default, comment="#",
                lines=default, atype=Float, linesep='\n',
                rowsize=10000, missing=0):
@@ -437,6 +443,11 @@ def str_array(arr, precision=5,col_sep=' ',row_sep="\n",ss=0):
     return row_sep.join(thestr)
 
 
+@deprecate_with_doc("""
+
+This function is replaced by numpy.savetxt which allows the same functionality
+through a different syntax.
+""")
 def write_array(fileobject, arr, separator=" ", linesep='\n',
                 precision=5, suppress_small=0, keep_open=0):
     """Write a rank-2 or less array to file represented by fileobject.
