@@ -19,5 +19,5 @@ from numpy.dual import register_func
 register_func('i0',i0)
 del register_func
 
-from numpy.testing import NumpyTest
-test = NumpyTest().test
+from numpy.testing import Tester
+test = Tester().test
